@@ -338,7 +338,7 @@
       (cons "^_[0-9]_[0-9]! "          'sisu-general-font-lock-red1)
 
       ;; url
-      (cons "\\(^\\|[ ]\\)http:[/][/][^ \t\n\r<]+" 'sisu-general-font-lock-blue2)
+      (cons "\\(^\\|[ ]\\)https?:[/][/][^ \t\n\r<]+" 'sisu-general-font-lock-blue2)
 
       ;; Comment Lines
       (cons "^% .*"                     'sisu-general-font-lock-blue1)
@@ -363,7 +363,7 @@
         (concat
           "\\({~^\\|{\\)"
           "\\([^}{]+\\)"
-          "\\(}http:[/][/][^ \r\n\t<]+\\)"
+          "\\(}https?:[/][/][^ \r\n\t<]+\\)"
         )
         '(1 sisu-general-font-lock-blue2 t)
         '(2 sisu-general-font-lock-red1 t)
