@@ -1,61 +1,59 @@
-# encoding: utf-8
-=begin
-
-* Name: SiSU
-
-** Description: documents, structuring, processing, publishing, search
-*** system environment, resource control and configuration details
-
-** Author: Ralph Amissah
-  [ralph@amissah.com]
-  [ralph.amissah@gmail.com]
-
-** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
-  All Rights Reserved.
-
-** License: GPL 3 or later:
-
-  SiSU, a framework for document structuring, publishing and search
-
-  Copyright (C) Ralph Amissah
-
-  This program is free software: you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation, either version 3 of the License, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-  more details.
-
-  You should have received a copy of the GNU General Public License along with
-  this program. If not, see [http://www.gnu.org/licenses/].
-
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-  [http://www.fsf.org/licensing/licenses/gpl.html]
-  [http://www.gnu.org/licenses/gpl.html]
-
-** SiSU uses:
-  * Standard SiSU markup syntax,
-  * Standard SiSU meta-markup syntax, and the
-  * Standard SiSU object citation numbering and system
-
-** Hompages:
-  [http://www.jus.uio.no/sisu]
-  [http://www.sisudoc.org]
-
-** Git
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/db_sqltxt.rb;hb=HEAD]
-
-=end
+#encoding: utf-8
+#- Name: SiSU
+#
+#  - Description: documents, structuring, processing, publishing, search
+#    db sql
+#
+#  - Author: Ralph Amissah
+#    <ralph.amissah@gmail.com>
+#
+#  - Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+#    2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019,
+#    2020, 2021, Ralph Amissah,
+#    All Rights Reserved.
+#
+#  - License: GPL 3 or later:
+#
+#    SiSU, a framework for document structuring, publishing and search
+#
+#    Copyright (C) Ralph Amissah
+#
+#    This program is free software: you can redistribute it and/or modify it
+#    under the terms of the GNU General Public License as published by the Free
+#    Software Foundation, either version 3 of the License, or (at your option)
+#    any later version.
+#
+#    This program is distributed in the hope that it will be useful, but WITHOUT
+#    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+#    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+#    more details.
+#
+#    You should have received a copy of the GNU General Public License along with
+#    this program. If not, see <http://www.gnu.org/licenses/>.
+#
+#    If you have Internet connection, the latest version of the GPL should be
+#    available at these locations:
+#    <http://www.fsf.org/licensing/licenses/gpl.html>
+#    <http://www.gnu.org/licenses/gpl.html>
+#
+#    <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+#
+#  - SiSU uses:
+#    - Standard SiSU markup syntax,
+#    - Standard SiSU meta-markup syntax, and the
+#    - Standard SiSU object citation numbering and system
+#
+#  - Homepages:
+#    <http://www.sisudoc.org>
+#
+#  - Git
+#    <https://git.sisudoc.org/projects/>
+#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
+#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
 module SiSU_DbText
   class Prepare
     def special_character_escape(str)
-      str=str.gsub(/'/m,"''"). #string.gsub!(/'/,"\047") #string.gsub!(/'/,"\\'")
+      str=str.to_s.gsub(/'/m,"''"). #string.gsub!(/'/,"\047") #string.gsub!(/'/,"\\'")
         gsub(/(\\)/m,'\1\1'). #ok but with warnings, double backslash on sqlite #str.gsub!(/[\\]/m,'\\x5C') #ok but with warnings, but not for sqlite #str.gsub!(/(\\)/m,'\1') #ok for sqlite not for pgsql
         gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/m,"<br>\n").
         gsub(/#{Mx[:tag_o]}\S+?#{Mx[:tag_c]}/m,''). #check
