@@ -1,57 +1,55 @@
-# encoding: utf-8
-=begin
-
-* Name: SiSU
-
-** Description: documents, structuring, processing, publishing, search
-*** html generation, processing
-
-** Author: Ralph Amissah
-  [ralph@amissah.com]
-  [ralph.amissah@gmail.com]
-
-** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
-  All Rights Reserved.
-
-** License: GPL 3 or later:
-
-  SiSU, a framework for document structuring, publishing and search
-
-  Copyright (C) Ralph Amissah
-
-  This program is free software: you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation, either version 3 of the License, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-  more details.
-
-  You should have received a copy of the GNU General Public License along with
-  this program. If not, see [http://www.gnu.org/licenses/].
-
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-  [http://www.fsf.org/licensing/licenses/gpl.html]
-  [http://www.gnu.org/licenses/gpl.html]
-
-** SiSU uses:
-  * Standard SiSU markup syntax,
-  * Standard SiSU meta-markup syntax, and the
-  * Standard SiSU object citation numbering and system
-
-** Hompages:
-  [http://www.jus.uio.no/sisu]
-  [http://www.sisudoc.org]
-
-** Git
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/html.rb;hb=HEAD]
-
-=end
+#encoding: utf-8
+#- Name: SiSU
+#
+#  - Description: documents, structuring, processing, publishing, search
+#    html
+#
+#  - Author: Ralph Amissah
+#    <ralph.amissah@gmail.com>
+#
+#  - Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+#    2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019,
+#    2020, 2021, Ralph Amissah,
+#    All Rights Reserved.
+#
+#  - License: GPL 3 or later:
+#
+#    SiSU, a framework for document structuring, publishing and search
+#
+#    Copyright (C) Ralph Amissah
+#
+#    This program is free software: you can redistribute it and/or modify it
+#    under the terms of the GNU General Public License as published by the Free
+#    Software Foundation, either version 3 of the License, or (at your option)
+#    any later version.
+#
+#    This program is distributed in the hope that it will be useful, but WITHOUT
+#    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+#    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+#    more details.
+#
+#    You should have received a copy of the GNU General Public License along with
+#    this program. If not, see <http://www.gnu.org/licenses/>.
+#
+#    If you have Internet connection, the latest version of the GPL should be
+#    available at these locations:
+#    <http://www.fsf.org/licensing/licenses/gpl.html>
+#    <http://www.gnu.org/licenses/gpl.html>
+#
+#    <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+#
+#  - SiSU uses:
+#    - Standard SiSU markup syntax,
+#    - Standard SiSU meta-markup syntax, and the
+#    - Standard SiSU object citation numbering and system
+#
+#  - Homepages:
+#    <http://www.sisudoc.org>
+#
+#  - Git
+#    <https://git.sisudoc.org/projects/>
+#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
+#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
 module SiSU_HTML
   begin
     require 'pstore'
@@ -361,7 +359,7 @@ WOK
         dob=@data
         linkname,link=dob.obj.strip,dob.ocn
         if link \
-        and link !~/#/ #% keep eye on link
+        and link.to_s !~/#/ #% keep eye on link
           SiSU_HTML_Format::ParagraphNumber.new(@md,link)
         end
         title=linkname
@@ -384,7 +382,7 @@ WOK
         dob=@data
         linkname,link=dob.obj.strip,dob.ocn
         if link \
-        and link !~/#/ #% keep eye on link
+        and link.to_s !~/#/ #% keep eye on link
           SiSU_HTML_Format::ParagraphNumber.new(@md,link)
         end
         title=if dob.obj !~/^Metadata$/ then linkname
@@ -430,7 +428,7 @@ WOK
         dob=@data
         linkname,ocn=dob.obj.strip,dob.ocn
         p_num=if ocn \
-        and ocn !~/#/
+        and ocn.to_s !~/#/
           SiSU_HTML_Format::ParagraphNumber.new(@md,ocn)
         else nil
         end
@@ -454,7 +452,7 @@ WOK
         dob=@data
         linkname,ocn=dob.obj.strip,dob.ocn
         p_num=if ocn \
-        and ocn !~/#/
+        and ocn.to_s !~/#/
           SiSU_HTML_Format::ParagraphNumber.new(@md,ocn)
         else nil
         end
@@ -526,7 +524,7 @@ WOK
         linkname,ocn=dob.obj.strip,dob.ocn
         toc={}
         if ocn \
-        and ocn !~/#/
+        and ocn.to_s !~/#/
           fnh={
             fn: @@seg_url,
           }
@@ -551,7 +549,7 @@ WOK
         linkname,ocn=dob.obj.strip,dob.ocn
         toc={}
         if ocn \
-        and ocn !~/#/
+        and ocn.to_s !~/#/
           fnh={
             fn: @@seg_url,
           }
