@@ -1,57 +1,55 @@
-# encoding: utf-8
-=begin
-
-* Name: SiSU
-
-** Description: documents, structuring, processing, publishing, search
-*** internationalisation
-
-** Author: Ralph Amissah
-  [ralph@amissah.com]
-  [ralph.amissah@gmail.com]
-
-** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
-  All Rights Reserved.
-
-** License: GPL 3 or later:
-
-  SiSU, a framework for document structuring, publishing and search
-
-  Copyright (C) Ralph Amissah
-
-  This program is free software: you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation, either version 3 of the License, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-  more details.
-
-  You should have received a copy of the GNU General Public License along with
-  this program. If not, see [http://www.gnu.org/licenses/].
-
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-  [http://www.fsf.org/licensing/licenses/gpl.html]
-  [http://www.gnu.org/licenses/gpl.html]
-
-** SiSU uses:
-  * Standard SiSU markup syntax,
-  * Standard SiSU meta-markup syntax, and the
-  * Standard SiSU object citation numbering and system
-
-** Hompages:
-  [http://www.jus.uio.no/sisu]
-  [http://www.sisudoc.org]
-
-** Git
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/prog_text_translation.rb;hb=HEAD]
-
-=end
+#encoding: utf-8
+#- Name: SiSU
+#
+#  - Description: documents, structuring, processing, publishing, search
+#    i18n
+#
+#  - Author: Ralph Amissah
+#    <ralph.amissah@gmail.com>
+#
+#  - Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+#    2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019,
+#    2020, 2021, Ralph Amissah,
+#    All Rights Reserved.
+#
+#  - License: GPL 3 or later:
+#
+#    SiSU, a framework for document structuring, publishing and search
+#
+#    Copyright (C) Ralph Amissah
+#
+#    This program is free software: you can redistribute it and/or modify it
+#    under the terms of the GNU General Public License as published by the Free
+#    Software Foundation, either version 3 of the License, or (at your option)
+#    any later version.
+#
+#    This program is distributed in the hope that it will be useful, but WITHOUT
+#    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+#    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+#    more details.
+#
+#    You should have received a copy of the GNU General Public License along with
+#    this program. If not, see <http://www.gnu.org/licenses/>.
+#
+#    If you have Internet connection, the latest version of the GPL should be
+#    available at these locations:
+#    <http://www.fsf.org/licensing/licenses/gpl.html>
+#    <http://www.gnu.org/licenses/gpl.html>
+#
+#    <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+#
+#  - SiSU uses:
+#    - Standard SiSU markup syntax,
+#    - Standard SiSU meta-markup syntax, and the
+#    - Standard SiSU object citation numbering and system
+#
+#  - Homepages:
+#    <http://www.sisudoc.org>
+#
+#  - Git
+#    <https://git.sisudoc.org/projects/>
+#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
+#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
 module SiSU_Translate
   require_relative 'se'                                 # se.rb
     include SiSU_Env; include SiSU_Param
@@ -336,7 +334,7 @@ module SiSU_Translate
     def author
       'Author'
     end
-    def author #dc
+    def creator #dc
       'Creator'
     end
     def contributor #dc
@@ -1627,74 +1625,3 @@ module SiSU_Translate
   end
 end
 __END__
-http://www.debian.org/international/l10n/po/
-http://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
-http://www.loc.gov/standards/iso639-2/php/code_list.php
-albanian           sq
-amharic            am
-arabic             ar
-armenian           hy
-asturian
-bahasai
-bahasam
-basque             eu
-bengali            bn
-brazil[ian]        pt_BR
-breton             br
-bulgarian          bg
-catalan            ca
-coptic
-croatian           hr
-czech              cs
-danish             da
-divehi
-dutch              nl
-english            en
-esperanto          eo
-estonian           et
-galician           gl
-german             de
-greek              el
-hebrew             he
-hindi              hi
-icelandic          is
-interlingua        ia
-irish              ga
-italian            it
-farsi
-finnish            fi
-french             fr
-lao                lo
-latin              la
-latvian            lv
-lithuanian         lt
-lsorbian
-magyar
-malayalam          ml
-marathi            mr
-norsk              no
-nynorsk            nn
-occitan            oc
-polish             pl
-portuges           pt
-romanian           ro
-russian            ru
-samin              se (check sami?)
-sanskrit           sa
-scottish            #  (gd (Gaelic (Scots)))
-serbian            sr
-slovak             sk
-slovenian          sl
-spanish            es
-swedish            sv
-syriac             #  (ar_SY (Arabic, as spoken in Syrian Arab Republic))
-tamil              ta
-telugu             te
-thai               th
-turkish            tr
-turkmen            tk
-ukrainian          uk
-urdu               ur
-usorbian
-vietnamese         vi
-welsh              cy
