@@ -1,57 +1,55 @@
-# encoding: utf-8
-=begin
-
-* Name: SiSU
-
-** Description: documents, structuring, processing, publishing, search
-*** system environment, resource control and configuration details
-
-** Author: Ralph Amissah
-  [ralph@amissah.com]
-  [ralph.amissah@gmail.com]
-
-** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
-  All Rights Reserved.
-
-** License: GPL 3 or later:
-
-  SiSU, a framework for document structuring, publishing and search
-
-  Copyright (C) Ralph Amissah
-
-  This program is free software: you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation, either version 3 of the License, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-  more details.
-
-  You should have received a copy of the GNU General Public License along with
-  this program. If not, see [http://www.gnu.org/licenses/].
-
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-  [http://www.fsf.org/licensing/licenses/gpl.html]
-  [http://www.gnu.org/licenses/gpl.html]
-
-** SiSU uses:
-  * Standard SiSU markup syntax,
-  * Standard SiSU meta-markup syntax, and the
-  * Standard SiSU object citation numbering and system
-
-** Hompages:
-  [http://www.jus.uio.no/sisu]
-  [http://www.sisudoc.org]
-
-** Git
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/shared_metadata.rb;hb=HEAD]
-
-=end
+#encoding: utf-8
+#- Name: SiSU
+#
+#  - Description: documents, structuring, processing, publishing, search
+#    shared
+#
+#  - Author: Ralph Amissah
+#    <ralph.amissah@gmail.com>
+#
+#  - Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+#    2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019,
+#    2020, 2021, Ralph Amissah,
+#    All Rights Reserved.
+#
+#  - License: GPL 3 or later:
+#
+#    SiSU, a framework for document structuring, publishing and search
+#
+#    Copyright (C) Ralph Amissah
+#
+#    This program is free software: you can redistribute it and/or modify it
+#    under the terms of the GNU General Public License as published by the Free
+#    Software Foundation, either version 3 of the License, or (at your option)
+#    any later version.
+#
+#    This program is distributed in the hope that it will be useful, but WITHOUT
+#    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+#    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+#    more details.
+#
+#    You should have received a copy of the GNU General Public License along with
+#    this program. If not, see <http://www.gnu.org/licenses/>.
+#
+#    If you have Internet connection, the latest version of the GPL should be
+#    available at these locations:
+#    <http://www.fsf.org/licensing/licenses/gpl.html>
+#    <http://www.gnu.org/licenses/gpl.html>
+#
+#    <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+#
+#  - SiSU uses:
+#    - Standard SiSU markup syntax,
+#    - Standard SiSU meta-markup syntax, and the
+#    - Standard SiSU object citation numbering and system
+#
+#  - Homepages:
+#    <http://www.sisudoc.org>
+#
+#  - Git
+#    <https://git.sisudoc.org/projects/>
+#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
+#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
 module SiSU_Metadata
   require_relative 'xml_parts'                          # xml_parts.rb
   require_relative 'xml_shared'                         # xml_shared.rb
@@ -72,7 +70,6 @@ module SiSU_Metadata
         content=if not content.nil?
           content=content.tr('"',"'").
             gsub(/&/,'&amp;')
-          content=SiSU_XML_Munge::Trans.new(@md).char_enc.utf8(content)
         else content
         end
       end
@@ -813,7 +810,6 @@ module SiSU_Metadata
     def xml_docbook
       def meta_para
         inf_xml=char_enc(@inf).amp
-        inf_xml=char_enc(inf_xml).utf8
         inf_xml=char_enc(inf_xml).br
         <<WOK
 #{Ax[:tab]}<#{@tag}>
@@ -829,7 +825,6 @@ WOK
     def html_display
       def meta_para
         inf_xml=char_enc(@inf).amp
-        inf_xml=char_enc(inf_xml).utf8
         inf_xml=char_enc(inf_xml).br
         %{<p class="norm">
   <b>#{@tag}</b>: #{inf_xml}
@@ -842,7 +837,6 @@ WOK
     end
     def xml_sax
       def meta_para
-        inf_xml=char_enc(@inf).utf8
         inf_xml=char_enc(inf_xml).br
         <<WOK
 <metadata>
@@ -861,7 +855,6 @@ WOK
     def xml_dom
       def meta_para
         inf_xml=char_enc(inf_xml).amp
-        inf_xml=char_enc(@inf).utf8
         inf_xml=char_enc(inf_xml).br
         <<WOK
 #{Ax[:tab]}<header>
@@ -880,7 +873,6 @@ WOK
     def xhtml_scroll
       def meta_para
         inf_xml=char_enc(inf_xml).amp
-        inf_xml=char_enc(@inf).utf8
         inf_xml=char_enc(inf_xml).br
         <<WOK
 #{Ax[:tab]}<metadata>
@@ -900,7 +892,6 @@ WOK
     def xhtml_display
       def meta_para
         inf_xml=char_enc(@inf).amp
-        inf_xml=char_enc(inf_xml).utf8
         inf_xml=char_enc(inf_xml).br
         %{<p class="norm">
   <b>#{@tag}</b>: #{inf_xml}
@@ -1158,9 +1149,14 @@ WOK
         tag,inf=tr.prefix_b,@md.notes.prefix_b
         meta << meta_para(tag,inf)
       end
-      if defined? @md.classify.identifier \
-      and @md.classify.identifier=~/\S+/
-        tag,inf=tr.identifier,@md.classify.identifier
+      if defined? @md.identifier.isbn \
+      and @md.identifier.isbn=~/\S+/
+        tag,inf=tr.cls_isbn,@md.identifier.isbn
+        meta << meta_para(tag,inf)
+      end
+      if defined? @md.identifier.oclc \
+      and @md.identifier.oclc=~/\S+/
+        tag,inf=tr.cls_oclc,@md.identifier.oclc
         meta << meta_para(tag,inf)
       end
       if defined? @md.original.source \
@@ -1369,3 +1365,4 @@ if @md.notes
   ]
   x.each {|y| p y if y}
 end
+__END__
