@@ -1,57 +1,55 @@
-# encoding: utf-8
-=begin
-
-* Name: SiSU
-
-** Description: documents, structuring, processing, publishing, search
-*** LaTeX formatting template, unicode utf-8 version, used for pdf
-
-** Author: Ralph Amissah
-  [ralph@amissah.com]
-  [ralph.amissah@gmail.com]
-
-** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
-  All Rights Reserved.
-
-** License: GPL 3 or later:
-
-  SiSU, a framework for document structuring, publishing and search
-
-  Copyright (C) Ralph Amissah
-
-  This program is free software: you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation, either version 3 of the License, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-  more details.
-
-  You should have received a copy of the GNU General Public License along with
-  this program. If not, see [http://www.gnu.org/licenses/].
-
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-  [http://www.fsf.org/licensing/licenses/gpl.html]
-  [http://www.gnu.org/licenses/gpl.html]
-
-** SiSU uses:
-  * Standard SiSU markup syntax,
-  * Standard SiSU meta-markup syntax, and the
-  * Standard SiSU object citation numbering and system
-
-** Hompages:
-  [http://www.jus.uio.no/sisu]
-  [http://www.sisudoc.org]
-
-** Git
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/texpdf_format.rb;hb=HEAD]
-
-=end
+#encoding: utf-8
+#- Name: SiSU
+#
+#  - Description: documents, structuring, processing, publishing, search
+#    texpdf
+#
+#  - Author: Ralph Amissah
+#    <ralph.amissah@gmail.com>
+#
+#  - Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+#    2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019,
+#    2020, 2021, Ralph Amissah,
+#    All Rights Reserved.
+#
+#  - License: GPL 3 or later:
+#
+#    SiSU, a framework for document structuring, publishing and search
+#
+#    Copyright (C) Ralph Amissah
+#
+#    This program is free software: you can redistribute it and/or modify it
+#    under the terms of the GNU General Public License as published by the Free
+#    Software Foundation, either version 3 of the License, or (at your option)
+#    any later version.
+#
+#    This program is distributed in the hope that it will be useful, but WITHOUT
+#    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+#    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+#    more details.
+#
+#    You should have received a copy of the GNU General Public License along with
+#    this program. If not, see <http://www.gnu.org/licenses/>.
+#
+#    If you have Internet connection, the latest version of the GPL should be
+#    available at these locations:
+#    <http://www.fsf.org/licensing/licenses/gpl.html>
+#    <http://www.gnu.org/licenses/gpl.html>
+#
+#    <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+#
+#  - SiSU uses:
+#    - Standard SiSU markup syntax,
+#    - Standard SiSU meta-markup syntax, and the
+#    - Standard SiSU object citation numbering and system
+#
+#  - Homepages:
+#    <http://www.sisudoc.org>
+#
+#  - Git
+#    <https://git.sisudoc.org/projects/>
+#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
+#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
 module SiSU_TeX_Pdf
   require_relative 'texpdf_parts'                        # texpdf_parts.rb
   @@table_pg_break_counter=1
@@ -732,11 +730,23 @@ module SiSU_TeX_Pdf
 \\setmainfont{#{texpdf_fontface}}
 \\setmonofont[Scale=0.85]{#{texpdf_fontface_mono}}
           WOK
+        elsif (tex_head_lang[:mainlang] == "english" \
+        && (tex_head_lang[:otherlang] == "english" \
+          || tex_head_lang[:otherlang] == "" \
+          || tex_head_lang[:otherlang].length == 0))
+          <<-WOK
+\\usepackage{polyglossia, ucs, fontspec, xltxtra, xunicode}
+\\setmainlanguage{#{tex_head_lang[:mainlang]}}
+\\setmainfont{#{texpdf_fontface}}
+\\setmonofont[Scale=0.85]{#{texpdf_fontface_mono}}
+% \\setsansfont{#{texpdf_fontface_sans}}
+% \\setromanfont{#{texpdf_fontface_serif}}
+          WOK
         else
           <<-WOK
 \\usepackage{polyglossia, ucs, fontspec, xltxtra, xunicode}
 \\setmainlanguage{#{tex_head_lang[:mainlang]}}
-\\setotherlanguage{#{tex_head_lang[:otherlang]}}
+\\setotherlanguage{english}
 \\setmainfont{#{texpdf_fontface}}
 \\setmonofont[Scale=0.85]{#{texpdf_fontface_mono}}
 % \\setsansfont{#{texpdf_fontface_sans}}
@@ -775,6 +785,7 @@ module SiSU_TeX_Pdf
       multicol=(@md.book_idx ? '\usepackage{multicol}' : '')
       <<-WOK
 #{tex_head_info}
+\\usepackage{geometry}
 \\documentclass[#{d[:fontsize]},#{d[:papertype]},titlepage]{scrartcl}        %with titlepage
 \\setlength{\\textheight}{#{d[:textheight]}mm} \\setlength{\\textwidth}{#{d[:textwidth]}mm}
 \\setlength{\\oddsidemargin}{#{d[:oddsidemargin]}} \\setlength{\\evensidemargin}{#{d[:evensidemargin]}}
@@ -788,6 +799,7 @@ module SiSU_TeX_Pdf
     def tex_head_paper_landscape(d)
       <<-WOK
 #{tex_head_info}
+\\usepackage{geometry}
 \\documentclass[#{d[:fontsize]},#{d[:papertype]},landscape,titlepage,twocolumn]{scrartcl}        %with titlepage
 \\setlength{\\textheight}{#{d[:textheight]}mm} \\setlength{\\textwidth}{#{d[:textwidth]}mm}
 \\setlength{\\oddsidemargin}{#{d[:oddsidemargin]}} \\setlength{\\evensidemargin}{#{d[:evensidemargin]}}
@@ -1628,4 +1640,3 @@ texlive-latex-extra
 texlive-latex-recommended
 texlive-plain-generic
 texlive-xetex
-
