@@ -1,57 +1,55 @@
-# encoding: utf-8
-=begin
-
-* Name: SiSU
-
-** Description: documents, structuring, processing, publishing, search
-*** system environment, screen colors text
-
-** Author: Ralph Amissah
-  [ralph@amissah.com]
-  [ralph.amissah@gmail.com]
-
-** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
-  All Rights Reserved.
-
-** License: GPL 3 or later:
-
-  SiSU, a framework for document structuring, publishing and search
-
-  Copyright (C) Ralph Amissah
-
-  This program is free software: you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation, either version 3 of the License, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-  more details.
-
-  You should have received a copy of the GNU General Public License along with
-  this program. If not, see [http://www.gnu.org/licenses/].
-
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-  [http://www.fsf.org/licensing/licenses/gpl.html]
-  [http://www.gnu.org/licenses/gpl.html]
-
-** SiSU uses:
-  * Standard SiSU markup syntax,
-  * Standard SiSU meta-markup syntax, and the
-  * Standard SiSU object citation numbering and system
-
-** Hompages:
-  [http://www.jus.uio.no/sisu]
-  [http://www.sisudoc.org]
-
-** Git
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
-  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/utils_screen_text_color.rb;hb=HEAD]
-
-=end
+#encoding: utf-8
+#- Name: SiSU
+#
+#  - Description: documents, structuring, processing, publishing, search
+#    utils
+#
+#  - Author: Ralph Amissah
+#    <ralph.amissah@gmail.com>
+#
+#  - Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+#    2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019,
+#    2020, 2021, Ralph Amissah,
+#    All Rights Reserved.
+#
+#  - License: GPL 3 or later:
+#
+#    SiSU, a framework for document structuring, publishing and search
+#
+#    Copyright (C) Ralph Amissah
+#
+#    This program is free software: you can redistribute it and/or modify it
+#    under the terms of the GNU General Public License as published by the Free
+#    Software Foundation, either version 3 of the License, or (at your option)
+#    any later version.
+#
+#    This program is distributed in the hope that it will be useful, but WITHOUT
+#    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+#    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+#    more details.
+#
+#    You should have received a copy of the GNU General Public License along with
+#    this program. If not, see <http://www.gnu.org/licenses/>.
+#
+#    If you have Internet connection, the latest version of the GPL should be
+#    available at these locations:
+#    <http://www.fsf.org/licensing/licenses/gpl.html>
+#    <http://www.gnu.org/licenses/gpl.html>
+#
+#    <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+#
+#  - SiSU uses:
+#    - Standard SiSU markup syntax,
+#    - Standard SiSU meta-markup syntax, and the
+#    - Standard SiSU object citation numbering and system
+#
+#  - Homepages:
+#    <http://www.sisudoc.org>
+#
+#  - Git
+#    <https://git.sisudoc.org/projects/>
+#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
+#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
 module SiSU_Screen
   class Color
     attr_accessor :off,:marker,:bold,:underline,:invert,:darkgrey_hi,:grey_hi,:pink_hi,:fuchsia_hi,:red_hi,:orange_hi,:yellow_hi,:brown_hi,:lightgreen_hi,:green_hi,:cyan_hi,:blue_hi,:navy_hi,:white,:white_bold,:grey,:pink,:fuchsia,:ruby,:red,:orange,:yellow,:brown,:green,:darkgreen,:cyan,:blue,:navy,:black
@@ -64,7 +62,7 @@ module SiSU_Screen
     def initialize(color_state,*txt)
       @color_state,@txt=color_state,txt
       @color_instruct=txt[0]
-      @cX=@@cX=if color_state==:on
+      @cX=if color_state==:on
         Color.new do
           self.off=self.white=self.white_bold=self.marker=self.bold=self.underline=self.invert=self.darkgrey_hi=self.grey_hi=self.pink_hi=self.fuchsia_hi=self.red_hi=self.orange_hi=self.yellow_hi=self.brown_hi=self.lightgreen_hi=self.green_hi=self.cyan_hi=self.blue_hi=self.navy_hi=self.grey=self.pink=self.fuchsia=self.ruby=self.red=self.orange=self.yellow=self.brown=self.green=self.darkgreen=self.cyan=self.blue=self.navy=self.black=''
         end
@@ -382,7 +380,7 @@ module SiSU_Screen
       puts %{\t#{@cX.grey}MetaVerse: MarshalLoad (creation of metaVerse skipped)#{@cX.off}}
     end
     def meta_verse_load
-      puts %{\t<<MetaVerse: MarshalLoad>>}
+      puts %{\t[ MetaVerse: MarshalLoad ]}
     end
     def html_title
       puts %{#{@cX.green_hi}#{@cX.black}HTML#{@cX.off*2}}
