@@ -389,7 +389,7 @@ proceed? }
     def self.changelog_header(vi)
       vn=version_number(vi)
       <<-WOK
-* sisu_#{vn}.orig.tar.xz (#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})
+- sisu_#{vn}.orig.tar.xz (#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})
   http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
       WOK
     end
@@ -437,7 +437,7 @@ proceed? }
     def self.changelog_header_pre_release(vi)
       vn=version_number(vi)
       <<-WOK
-* sisu_#{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release)
+- sisu_#{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release)
   http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
       WOK
     end
@@ -569,7 +569,7 @@ Gem::Specification.new do |s|
   s.homepage       = '#{Project_details.homepage}'
   s.authors        = ["Ralph Amissah"]
   s.email          = 'ralph.amissah@gmail.com'
-  s.license        = 'GPL3'
+  s.license        = 'GPL-3.0-or-later'
   s.files          = Dir['lib/#{Project_details.name.downcase}.rb'] +
                      Dir['lib/#{Project_details.name.downcase}/*.rb'] +
                      Dir['data/#{Project_details.name.downcase}/version.yml'] +
@@ -592,7 +592,7 @@ Gem::Specification.new do |s|
   s.homepage       = '#{Project_details.homepage}'
   s.authors        = ["Ralph Amissah"]
   s.email          = 'ralph.amissah@gmail.com'
-  s.license        = 'GPL3'
+  s.license        = 'GPL-3.0-or-later'
   s.files          = `git ls-files -z lib`.split("\x0") +
                      Dir['data/#{Project_details.name.downcase}/version.yml'] +
                      Dir['data/#{Project_details.name.downcase}/image/*'] +
